==> cdktf-cdktf-provider-opentelekomcloud-0.0.85.tar.gz: package/lib/index.d.ts <==
export * from './antiddos-v1';
export * from './as-configuration-v1';
export * from './as-group-v1';
export * from './as-policy-v1';
export * from './as-policy-v2';
export * from './blockstorage-volume-v2';
export * from './cbr-policy-v3';
export * from './cbr-vault-v3';
export * from './cce-addon-v3';
export * from './cce-cluster-v3';
export * from './cce-node-pool-v3';
export * from './cce-node-v3';
export * from './ces-alarmrule';
export * from './compute-bms-server-v2';
export * from './compute-bms-tags-v2';
export * from './compute-floatingip-associate-v2';
export * from './compute-floatingip-v2';
export * from './compute-instance-v2';
export * from './compute-keypair-v2';
export * from './compute-secgroup-v2';
export * from './compute-servergroup-v2';
export * from './compute-volume-attach-v2';
export * from './csbs-backup-policy-v1';
export * from './csbs-backup-v1';
export * from './css-cluster-v1';
export * from './css-snapshot-configuration-v1';
export * from './cts-tracker-v1';
export * from './dcs-instance-v1';
export * from './dds-instance-v3';
export * from './deh-host-v1';
export * from './dms-group-v1';
export * from './dms-instance-v1';
export * from './dms-queue-v1';
export * from './dns-ptrrecord-v2';
export * from './dns-recordset-v2';
export * from './dns-zone-v2';
export * from './ecs-instance-v1';
export * from './elb-backend';
export * from './elb-health';
export * from './elb-listener';
export * from './elb-loadbalancer';
export * from './evs-volume-v3';
export * from './fw-firewall-group-v2';
export * from './fw-policy-v2';
export * from './fw-rule-v2';
export * from './identity-agency-v3';
export * from './identity-credential-v3';
export * from './identity-group-membership-v3';
export * from './identity-group-v3';
export * from './identity-mapping-v3';
export * from './identity-project-v3';
export * from './identity-protocol-v3';
export * from './identity-provider-v3';
export * from './identity-role-assignment-v3';
export * from './identity-role-v3';
export * from './identity-user-group-membership-v3';
export * from './identity-user-v3';
export * from './images-image-access-accept-v2';
export * from './images-image-access-v2';
export * from './images-image-v2';
export * from './ims-data-image-v2';
export * from './ims-image-v2';
export * from './kms-grant-v1';
export * from './kms-key-v1';
export * from './lb-certificate-v2';
export * from './lb-certificate-v3';
export * from './lb-l7policy-v2';
export * from './lb-l7rule-v2';
export * from './lb-listener-v2';
export * from './lb-listener-v3';
export * from './lb-loadbalancer-v2';
export * from './lb-loadbalancer-v3';
export * from './lb-member-v2';
export * from './lb-member-v3';
export * from './lb-monitor-v2';
export * from './lb-monitor-v3';
export * from './lb-policy-v3';
export * from './lb-pool-v2';
export * from './lb-pool-v3';
export * from './lb-rule-v3';
export * from './lb-whitelist-v2';
export * from './logtank-group-v2';
export * from './logtank-topic-v2';
export * from './mrs-cluster-v1';
export * from './mrs-job-v1';
export * from './nat-dnat-rule-v2';
export * from './nat-gateway-v2';
export * from './nat-snat-rule-v2';
export * from './networking-floatingip-associate-v2';
export * from './networking-floatingip-v2';
export * from './networking-network-v2';
export * from './networking-port-v2';
export * from './networking-router-interface-v2';
export * from './networking-router-route-v2';
export * from './networking-router-v2';
export * from './networking-secgroup-rule-v2';
export * from './networking-secgroup-v2';
export * from './networking-subnet-v2';
export * from './networking-vip-associate-v2';
export * from './networking-vip-v2';
export * from './obs-bucket';
export * from './obs-bucket-object';
export * from './obs-bucket-policy';
export * from './rds-instance-v1';
export * from './rds-instance-v3';
export * from './rds-parametergroup-v3';
export * from './rds-read-replica-v3';
export * from './rts-software-config-v1';
export * from './rts-software-deployment-v1';
export * from './rts-stack-v1';
export * from './s3-bucket';
export * from './s3-bucket-object';
export * from './s3-bucket-policy';
export * from './sdrs-protected-instance-v1';
export * from './sdrs-protectiongroup-v1';
export * from './sfs-file-system-v2';
export * from './sfs-share-access-rules-v2';
export * from './sfs-turbo-share-v1';
export * from './smn-subscription-v2';
export * from './smn-topic-attribute-v2';
export * from './smn-topic-v2';
export * from './swr-domain-v2';
export * from './swr-organization-permissions-v2';
export * from './swr-organization-v2';
export * from './swr-repository-v2';
export * from './vbs-backup-policy-v2';
export * from './vbs-backup-share-v2';
export * from './vbs-backup-v2';
export * from './vpc-bandwidth-associate-v2';
export * from './vpc-bandwidth-v2';
export * from './vpc-eip-v1';
export * from './vpc-flow-log-v1';
export * from './vpc-peering-connection-accepter-v2';
export * from './vpc-peering-connection-v2';
export * from './vpc-route-v2';
export * from './vpc-subnet-v1';
export * from './vpc-v1';
export * from './vpcep-endpoint-v1';
export * from './vpcep-service-v1';
export * from './vpnaas-endpoint-group-v2';
export * from './vpnaas-ike-policy-v2';
export * from './vpnaas-ipsec-policy-v2';
export * from './vpnaas-service-v2';
export * from './vpnaas-site-connection-v2';
export * from './waf-alarm-notification-v1';
export * from './waf-ccattackprotection-rule-v1';
export * from './waf-certificate-v1';
export * from './waf-datamasking-rule-v1';
export * from './waf-domain-v1';
export * from './waf-falsealarmmasking-rule-v1';
export * from './waf-policy-v1';
export * from './waf-preciseprotection-rule-v1';
export * from './waf-webtamperprotection-rule-v1';
export * from './waf-whiteblackip-rule-v1';
export * from './data-opentelekomcloud-antiddos-v1';
export * from './data-opentelekomcloud-cce-cluster-v3';
export * from './data-opentelekomcloud-cce-node-ids-v3';
export * from './data-opentelekomcloud-cce-node-v3';
export * from './data-opentelekomcloud-compute-availability-zones-v2';
export * from './data-opentelekomcloud-compute-bms-flavors-v2';
export * from './data-opentelekomcloud-compute-bms-keypairs-v2';
export * from './data-opentelekomcloud-compute-bms-nic-v2';
export * from './data-opentelekomcloud-compute-bms-server-v2';
export * from './data-opentelekomcloud-compute-flavor-v2';
export * from './data-opentelekomcloud-csbs-backup-policy-v1';
export * from './data-opentelekomcloud-csbs-backup-v1';
export * from './data-opentelekomcloud-css-flavor-v1';
export * from './data-opentelekomcloud-cts-tracker-v1';
export * from './data-opentelekomcloud-dcs-az-v1';
export * from './data-opentelekomcloud-dcs-maintainwindow-v1';
export * from './data-opentelekomcloud-dcs-product-v1';
export * from './data-opentelekomcloud-dds-flavors-v3';
export * from './data-opentelekomcloud-dds-instance-v3';
export * from './data-opentelekomcloud-deh-host-v1';
export * from './data-opentelekomcloud-deh-server-v1';
export * from './data-opentelekomcloud-dms-az-v1';
export * from './data-opentelekomcloud-dms-maintainwindow-v1';
export * from './data-opentelekomcloud-dms-product-v1';
export * from './data-opentelekomcloud-dns-zone-v2';
export * from './data-opentelekomcloud-identity-auth-scope-v3';
export * from './data-opentelekomcloud-identity-credential-v3';
export * from './data-opentelekomcloud-identity-group-v3';
export * from './data-opentelekomcloud-identity-project-v3';
export * from './data-opentelekomcloud-identity-role-v3';
export * from './data-opentelekomcloud-identity-user-v3';
export * from './data-opentelekomcloud-images-image-v2';
export * from './data-opentelekomcloud-kms-data-key-v1';
export * from './data-opentelekomcloud-kms-key-v1';
export * from './data-opentelekomcloud-lb-certificate-v3';
export * from './data-opentelekomcloud-lb-flavor-v3';
export * from './data-opentelekomcloud-lb-listener-v3';
export * from './data-opentelekomcloud-lb-loadbalancer-v3';
export * from './data-opentelekomcloud-networking-network-v2';
export * from './data-opentelekomcloud-networking-port-v2';
export * from './data-opentelekomcloud-networking-secgroup-rule-ids-v2';
export * from './data-opentelekomcloud-networking-secgroup-v2';
export * from './data-opentelekomcloud-obs-bucket';
export * from './data-opentelekomcloud-obs-bucket-object';
export * from './data-opentelekomcloud-rds-flavors-v1';
export * from './data-opentelekomcloud-rds-flavors-v3';
export * from './data-opentelekomcloud-rds-versions-v3';
export * from './data-opentelekomcloud-rts-software-config-v1';
export * from './data-opentelekomcloud-rts-software-deployment-v1';
export * from './data-opentelekomcloud-rts-stack-resource-v1';
export * from './data-opentelekomcloud-rts-stack-v1';
export * from './data-opentelekomcloud-s3-bucket-object';
export * from './data-opentelekomcloud-sdrs-domain-v1';
export * from './data-opentelekomcloud-sfs-file-system-v2';
export * from './data-opentelekomcloud-sfs-turbo-share-v1';
export * from './data-opentelekomcloud-vbs-backup-policy-v2';
export * from './data-opentelekomcloud-vbs-backup-v2';
export * from './data-opentelekomcloud-vpc-bandwidth';
export * from './data-opentelekomcloud-vpc-eip-v1';
export * from './data-opentelekomcloud-vpc-peering-connection-v2';
export * from './data-opentelekomcloud-vpc-route-ids-v2';
export * from './data-opentelekomcloud-vpc-route-v2';
export * from './data-opentelekomcloud-vpc-subnet-ids-v1';
export * from './data-opentelekomcloud-vpc-subnet-v1';
export * from './data-opentelekomcloud-vpc-v1';
export * from './data-opentelekomcloud-vpcep-public-service-v1';
export * from './data-opentelekomcloud-vpcep-service-v1';
export * from './data-opentelekomcloud-vpnaas-service-v2';
export * from './opentelekomcloud-provider';

==> cdktf-cdktf-provider-opentelekomcloud-0.3.20.tar.gz: package/lib/index.d.ts <==
export * from './antiddos-v1';
export * from './as-configuration-v1';
export * from './as-group-v1';
export * from './as-policy-v1';
export * from './as-policy-v2';
export * from './blockstorage-volume-v2';
export * from './cbr-policy-v3';
export * from './cbr-vault-v3';
export * from './cce-addon-v3';
export * from './cce-cluster-v3';
export * from './cce-node-pool-v3';
export * from './cce-node-v3';
export * from './ces-alarmrule';
export * from './compute-bms-server-v2';
export * from './compute-bms-tags-v2';
export * from './compute-floatingip-associate-v2';
export * from './compute-floatingip-v2';
export * from './compute-instance-v2';
export * from './compute-keypair-v2';
export * from './compute-secgroup-v2';
export * from './compute-servergroup-v2';
export * from './compute-volume-attach-v2';
export * from './csbs-backup-policy-v1';
export * from './csbs-backup-v1';
export * from './css-cluster-v1';
export * from './css-snapshot-configuration-v1';
export * from './cts-tracker-v1';
export * from './dcs-instance-v1';
export * from './dds-instance-v3';
export * from './deh-host-v1';
export * from './dms-group-v1';
export * from './dms-instance-v1';
export * from './dms-queue-v1';
export * from './dns-ptrrecord-v2';
export * from './dns-recordset-v2';
export * from './dns-zone-v2';
export * from './ecs-instance-v1';
export * from './evs-volume-v3';
export * from './fw-firewall-group-v2';
export * from './fw-policy-v2';
export * from './fw-rule-v2';
export * from './identity-agency-v3';
export * from './identity-credential-v3';
export * from './identity-group-membership-v3';
export * from './identity-group-v3';
export * from './identity-mapping-v3';
export * from './identity-project-v3';
export * from './identity-protocol-v3';
export * from './identity-provider-v3';
export * from './identity-role-assignment-v3';
export * from './identity-role-v3';
export * from './identity-user-group-membership-v3';
export * from './identity-user-v3';
export * from './images-image-access-accept-v2';
export * from './images-image-access-v2';
export * from './images-image-v2';
export * from './ims-data-image-v2';
export * from './ims-image-v2';
export * from './kms-grant-v1';
export * from './kms-key-v1';
export * from './lb-certificate-v2';
export * from './lb-certificate-v3';
export * from './lb-l7policy-v2';
export * from './lb-l7rule-v2';
export * from './lb-listener-v2';
export * from './lb-listener-v3';
export * from './lb-loadbalancer-v2';
export * from './lb-loadbalancer-v3';
export * from './lb-member-v2';
export * from './lb-member-v3';
export * from './lb-monitor-v2';
export * from './lb-monitor-v3';
export * from './lb-policy-v3';
export * from './lb-pool-v2';
export * from './lb-pool-v3';
export * from './lb-rule-v3';
export * from './lb-whitelist-v2';
export * from './logtank-group-v2';
export * from './logtank-topic-v2';
export * from './mrs-cluster-v1';
export * from './mrs-job-v1';
export * from './nat-dnat-rule-v2';
export * from './nat-gateway-v2';
export * from './nat-snat-rule-v2';
export * from './networking-floatingip-associate-v2';
export * from './networking-floatingip-v2';
export * from './networking-network-v2';
export * from './networking-port-v2';
export * from './networking-router-interface-v2';
export * from './networking-router-route-v2';
export * from './networking-router-v2';
export * from './networking-secgroup-rule-v2';
export * from './networking-secgroup-v2';
export * from './networking-subnet-v2';
export * from './networking-vip-associate-v2';
export * from './networking-vip-v2';
export * from './obs-bucket';
export * from './obs-bucket-object';
export * from './obs-bucket-policy';
export * from './rds-instance-v1';
export * from './rds-instance-v3';
export * from './rds-parametergroup-v3';
export * from './rds-read-replica-v3';
export * from './rts-software-config-v1';
export * from './rts-software-deployment-v1';
export * from './rts-stack-v1';
export * from './s3-bucket';
export * from './s3-bucket-object';
export * from './s3-bucket-policy';
export * from './sdrs-protected-instance-v1';
export * from './sdrs-protectiongroup-v1';
export * from './sfs-file-system-v2';
export * from './sfs-share-access-rules-v2';
export * from './sfs-turbo-share-v1';
export * from './smn-subscription-v2';
export * from './smn-topic-attribute-v2';
export * from './smn-topic-v2';
export * from './swr-domain-v2';
export * from './swr-organization-permissions-v2';
export * from './swr-organization-v2';
export * from './swr-repository-v2';
export * from './vbs-backup-policy-v2';
export * from './vbs-backup-share-v2';
export * from './vbs-backup-v2';
export * from './vpc-bandwidth-associate-v2';
export * from './vpc-bandwidth-v2';
export * from './vpc-eip-v1';
export * from './vpc-flow-log-v1';
export * from './vpc-peering-connection-accepter-v2';
export * from './vpc-peering-connection-v2';
export * from './vpc-route-v2';
export * from './vpc-subnet-v1';
export * from './vpc-v1';
export * from './vpcep-endpoint-v1';
export * from './vpcep-service-v1';
export * from './vpnaas-endpoint-group-v2';
export * from './vpnaas-ike-policy-v2';
export * from './vpnaas-ipsec-policy-v2';
export * from './vpnaas-service-v2';
export * from './vpnaas-site-connection-v2';
export * from './waf-alarm-notification-v1';
export * from './waf-ccattackprotection-rule-v1';
export * from './waf-certificate-v1';
export * from './waf-datamasking-rule-v1';
export * from './waf-domain-v1';
export * from './waf-falsealarmmasking-rule-v1';
export * from './waf-policy-v1';
export * from './waf-preciseprotection-rule-v1';
export * from './waf-webtamperprotection-rule-v1';
export * from './waf-whiteblackip-rule-v1';
export * from './data-opentelekomcloud-antiddos-v1';
export * from './data-opentelekomcloud-cce-cluster-v3';
export * from './data-opentelekomcloud-cce-node-ids-v3';
export * from './data-opentelekomcloud-cce-node-v3';
export * from './data-opentelekomcloud-compute-availability-zones-v2';
export * from './data-opentelekomcloud-compute-bms-flavors-v2';
export * from './data-opentelekomcloud-compute-bms-keypairs-v2';
export * from './data-opentelekomcloud-compute-bms-nic-v2';
export * from './data-opentelekomcloud-compute-bms-server-v2';
export * from './data-opentelekomcloud-compute-flavor-v2';
export * from './data-opentelekomcloud-csbs-backup-policy-v1';
export * from './data-opentelekomcloud-csbs-backup-v1';
export * from './data-opentelekomcloud-css-flavor-v1';
export * from './data-opentelekomcloud-cts-tracker-v1';
export * from './data-opentelekomcloud-dcs-az-v1';
export * from './data-opentelekomcloud-dcs-maintainwindow-v1';
export * from './data-opentelekomcloud-dcs-product-v1';
export * from './data-opentelekomcloud-dds-flavors-v3';
export * from './data-opentelekomcloud-dds-instance-v3';
export * from './data-opentelekomcloud-deh-host-v1';
export * from './data-opentelekomcloud-deh-server-v1';
export * from './data-opentelekomcloud-dms-az-v1';
export * from './data-opentelekomcloud-dms-maintainwindow-v1';
export * from './data-opentelekomcloud-dms-product-v1';
export * from './data-opentelekomcloud-dns-zone-v2';
export * from './data-opentelekomcloud-identity-auth-scope-v3';
export * from './data-opentelekomcloud-identity-credential-v3';
export * from './data-opentelekomcloud-identity-group-v3';
export * from './data-opentelekomcloud-identity-project-v3';
export * from './data-opentelekomcloud-identity-role-v3';
export * from './data-opentelekomcloud-identity-user-v3';
export * from './data-opentelekomcloud-images-image-v2';
export * from './data-opentelekomcloud-kms-data-key-v1';
export * from './data-opentelekomcloud-kms-key-v1';
export * from './data-opentelekomcloud-lb-certificate-v3';
export * from './data-opentelekomcloud-lb-flavor-v3';
export * from './data-opentelekomcloud-lb-listener-v3';
export * from './data-opentelekomcloud-lb-loadbalancer-v3';
export * from './data-opentelekomcloud-networking-network-v2';
export * from './data-opentelekomcloud-networking-port-v2';
export * from './data-opentelekomcloud-networking-secgroup-rule-ids-v2';
export * from './data-opentelekomcloud-networking-secgroup-v2';
export * from './data-opentelekomcloud-obs-bucket';
export * from './data-opentelekomcloud-obs-bucket-object';
export * from './data-opentelekomcloud-rds-flavors-v1';
export * from './data-opentelekomcloud-rds-flavors-v3';
export * from './data-opentelekomcloud-rds-versions-v3';
export * from './data-opentelekomcloud-rts-software-config-v1';
export * from './data-opentelekomcloud-rts-software-deployment-v1';
export * from './data-opentelekomcloud-rts-stack-resource-v1';
export * from './data-opentelekomcloud-rts-stack-v1';
export * from './data-opentelekomcloud-s3-bucket-object';
export * from './data-opentelekomcloud-sdrs-domain-v1';
export * from './data-opentelekomcloud-sfs-file-system-v2';
export * from './data-opentelekomcloud-sfs-turbo-share-v1';
export * from './data-opentelekomcloud-vbs-backup-policy-v2';
export * from './data-opentelekomcloud-vbs-backup-v2';
export * from './data-opentelekomcloud-vpc-bandwidth';
export * from './data-opentelekomcloud-vpc-bandwidth-v2';
export * from './data-opentelekomcloud-vpc-eip-v1';
export * from './data-opentelekomcloud-vpc-peering-connection-v2';
export * from './data-opentelekomcloud-vpc-route-ids-v2';
export * from './data-opentelekomcloud-vpc-route-v2';
export * from './data-opentelekomcloud-vpc-subnet-ids-v1';
export * from './data-opentelekomcloud-vpc-subnet-v1';
export * from './data-opentelekomcloud-vpc-v1';
export * from './data-opentelekomcloud-vpcep-public-service-v1';
export * from './data-opentelekomcloud-vpcep-service-v1';
export * from './data-opentelekomcloud-vpnaas-service-v2';
export * from './opentelekomcloud-provider';
